<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use App\Models\Plan;
use Illuminate\Http\Request;

class PlanController extends Controller
{

    public function plan()
{
    $pageTitle = 'Plans';
    $plans = Plan::orderBy('price', 'asc')->paginate(10);
    return view('admin.plan.index', compact('pageTitle', 'plans'));
}

public function planSave(Request $request)
{
    $request->validate([
        'name'                => 'required|string|max:255',
        'price'               => 'required|numeric|min:0',
        'bv'                  => 'required|integer|min:0',
        'ref_com'             => 'required|numeric|min:0',
        'max_pairs_per_day'   => 'required|numeric|min:0',
        'infinite_pairs'      => 'required|numeric|min:0',
        'plan_picture'        => 'nullable|image|mimes:jpeg,png,jpg,gif|max:2048'
    ]);

    $plan = $request->id ? Plan::findOrFail($request->id) : new Plan();

    $plan->name              = $request->name;
    $plan->price             = $request->price;
    $plan->bv                = $request->bv;
    $plan->ref_com           = $request->ref_com;
    $plan->max_pairs_per_day = $request->max_pairs_per_day;
    $plan->infinite_pairs    = $request->infinite_pairs;

    // Handle Plan Picture Upload
    if ($request->hasFile('plan_picture')) {
        $file = $request->file('plan_picture');
        $fileName = time() . '.' . $file->getClientOriginalExtension();
        $file->move(public_path('assets/images/plan/'), $fileName);
        $plan->plan_picture = $fileName;
    }

    $plan->save();

    return back()->with('success', 'Plan saved successfully');
}


    public function status($id)
    {
        return Plan::changeStatus($id);
    }
}
