<?php

namespace App\Services;

use App\Models\HouseFundWallet;
use App\Models\User;
use Illuminate\Support\Facades\DB;

class HouseFundWalletService {
    protected $contributionRate = 5; // 5% of earnings

    public function processMonthlyContribution(User $user, float $earnings) {
        DB::transaction(function () use ($user, $earnings) {
            $contribution = ($earnings * $this->contributionRate) / 100;
            $wallet = HouseFundWallet::firstOrCreate(['user_id' => $user->id]);

            $wallet->increment('balance', $contribution);
            $wallet->increment('monthly_contribution', $contribution);
        });
    }

    public function redeemFunds(User $user) {
        $wallet = HouseFundWallet::where('user_id', $user->id)->first();

        if (!$wallet || $wallet->balance < $wallet->redeem_threshold) {
            return false; // Not eligible for redemption
        }

        $wallet->update(['balance' => 0, 'monthly_contribution' => 0]);

        return true;
    }
}
