<?php

namespace App\Services;

use App\Models\TreeCommission;
use App\Models\User;
use Illuminate\Support\Facades\DB;

class TreeCommissionService {
    protected $generationRates = [10, 8, 6, 5, 4, 3, 2, 2, 1, 1]; // % per generation

    public function distributeCommission(User $referrer, float $purchaseAmount) {
        DB::transaction(function () use ($referrer, $purchaseAmount) {
            $upline = $this->getUpline($referrer);
            
            foreach ($upline as $generation => $user) {
                $commissionPercentage = $this->generationRates[$generation] ?? 0;
                $commissionAmount = ($purchaseAmount * $commissionPercentage) / 100;

                if ($commissionAmount > 0) {
                    TreeCommission::create([
                        'user_id' => $user->id,
                        'referrer_id' => $referrer->id,
                        'generation' => $generation + 1,
                        'commission_percentage' => $commissionPercentage,
                        'amount' => $commissionAmount
                    ]);
                }
            }
        });
    }

    private function getUpline(User $user) {
        $upline = [];
        $current = $user;

        for ($i = 0; $i < 10; $i++) {
            if (!$current->referrer) break;
            $current = $current->referrer;
            $upline[$i] = $current;
        }

        return $upline;
    }
}
