@php
    // Ensure sidebar links are properly decoded
    $sideBarLinks = json_decode($sidenav, true) ?? [];
@endphp

<div class="sidebar bg--dark">
    <button class="res-sidebar-close-btn"><i class="las la-times"></i></button>
    <div class="sidebar__inner">
        <div class="sidebar__logo">
            <a href="{{ route('admin.dashboard') }}" class="sidebar__main-logo">
                <img src="{{ siteLogo('dark') }}" alt="Admin Dashboard Logo">
            </a>
        </div>

        <div class="sidebar__menu-wrapper">
            <ul class="sidebar__menu">
                @foreach($sideBarLinks as $key => $data)
                    {{-- Sidebar Section Header --}}
                    @if (!empty($data['header']))
                        <li class="sidebar__menu-header">{{ __($data['header']) }}</li>
                    @endif

                    {{-- Check if there's a submenu --}}
                    @if (!empty($data['submenu']))
                        <li class="sidebar-menu-item sidebar-dropdown">
                            <a href="javascript:void(0)" class="{{ menuActive($data['menu_active'] ?? '', 3) }}">
                                <i class="menu-icon {{ $data['icon'] ?? 'las la-bars' }}"></i>
                                <span class="menu-title">{{ __($data['title'] ?? 'Unnamed Menu') }}</span>

                                {{-- Display counter badge if exists --}}
                                @foreach($data['counters'] ?? [] as $counter)
                                    @if(isset($$counter) && $$counter > 0)
                                        <span class="menu-badge menu-badge-level-one bg--warning ms-auto">
                                            <i class="fas fa-exclamation"></i>
                                        </span>
                                        @break
                                    @endif
                                @endforeach
                            </a>

                            {{-- Submenu Items --}}
                            <div class="sidebar-submenu {{ menuActive($data['menu_active'] ?? '', 2) }}">
                                <ul>
                                    @foreach($data['submenu'] as $menu)
                                        @php
                                            $submenuParams = [];
                                            if (!empty($menu['params'])) {
                                                foreach ($menu['params'] as $submenuParamVal) {
                                                    $submenuParams[] = array_values((array)$submenuParamVal)[0];
                                                }
                                            }
                                        @endphp

                                        @if(Route::has($menu['route_name'] ?? ''))
                                            <li class="sidebar-menu-item {{ menuActive($menu['menu_active'] ?? '') }}">
                                                <a href="{{ route($menu['route_name'], $submenuParams) }}" class="nav-link">
                                                    <i class="menu-icon las la-dot-circle"></i>
                                                    <span class="menu-title">{{ __($menu['title'] ?? 'Unnamed Submenu') }}</span>

                                                    {{-- Show counter if exists --}}
                                                    @php $counter = $menu['counter'] ?? null; @endphp
                                                    @if(isset($$counter) && $$counter)
                                                        <span class="menu-badge bg--info ms-auto">{{ $$counter }}</span>
                                                    @endif
                                                </a>
                                            </li>
                                        @endif
                                    @endforeach
                                </ul>
                            </div>
                        </li>
                    @else
                        {{-- Main menu item --}}
                        @php
                            $mainParams = [];
                            if (!empty($data['params'])) {
                                foreach ($data['params'] as $paramVal) {
                                    $mainParams[] = array_values((array)$paramVal)[0];
                                }
                            }
                        @endphp

                        @if(Route::has($data['route_name'] ?? ''))
                            <li class="sidebar-menu-item {{ menuActive($data['menu_active'] ?? '') }}">
                                <a href="{{ route($data['route_name'], $mainParams) }}" class="nav-link">
                                    <i class="menu-icon {{ $data['icon'] ?? 'las la-bars' }}"></i>
                                    <span class="menu-title">{{ __($data['title'] ?? 'Unnamed Menu') }}</span>

                                    {{-- Show counter if exists --}}
                                    @php $counter = $data['counter'] ?? null; @endphp
                                    @if(isset($$counter) && $$counter)
                                        <span class="menu-badge bg--info ms-auto">{{ $$counter }}</span>
                                    @endif
                                </a>
                            </li>
                        @endif
                    @endif
                @endforeach
            </ul>
        </div>

        {{-- Version Information --}}
        <div class="version-info text-center text-uppercase">
            @if(function_exists('systemDetails'))
                <span class="text--primary">{{ __(systemDetails()['name'] ?? 'System') }}</span>
                <span class="text--success">@lang('V'){{ systemDetails()['version'] ?? '1.0' }} </span>
            @else
                <span class="text--primary">System Name</span>
                <span class="text--success">@lang('V')1.0</span>
            @endif
        </div>
    </div>
</div>
<!-- Sidebar End -->

@push('script')
    <script>
        document.addEventListener("DOMContentLoaded", function() {
            let activeMenuItem = document.querySelector('.sidebar__menu-wrapper .active');
            if (activeMenuItem) {
                document.querySelector('.sidebar__menu-wrapper').scrollTop = activeMenuItem.offsetTop - 320;
            }
        });
    </script>
@endpush
