@extends('admin.layouts.app')

@section('panel')
    <div class="row">
        <div class="col-lg-12">
            <div class="card">
                <div class="card-body p-0">
                    <div class="table-responsive--md table-responsive">
                        <table class="table--light style--two table">
                            <thead>
                                <tr>
                                    <th>@lang('Name')</th>
                                    <th>@lang('Price')</th>
                                    <th>@lang('Business Volume (BV)')</th>
                                    <th>@lang('Referral Commission')</th>
                                    <th>@lang('Max Pairs/Day')</th>
                                    <th>@lang('Infinite Pairs')</th>
                                    <th>@lang('Plan Picture')</th>
                                    <th>@lang('Status')</th>
                                    <th>@lang('Action')</th>
                                </tr>
                            </thead>
                            <tbody>
                                @forelse($plans as $plan)
                                    <tr>
                                        <td>{{ $plan->name }}</td>
                                        <td>{{ showAmount($plan->price) }}</td>
                                        <td>{{ $plan->bv }}</td>
                                        <td>{{ showAmount($plan->ref_com) }}</td>
                                        <td>{{ $plan->max_pairs_per_day }}</td>
                                        <td>{{ $plan->infinite_pairs }}</td>
                                        <td>
                                            @if ($plan->plan_picture)
                                                <img src="{{ asset('assets/images/plan/' . $plan->plan_picture) }}" 
                                                     class="w-80 img-thumbnail" alt="Plan Image">
                                            @else
                                                <img src="{{ asset('assets/images/plan/default.jpg') }}" 
                                                     class="w-80 img-thumbnail" alt="Default Image">
                                            @endif
                                        </td>
                                        <td>@php echo $plan->statusBadge @endphp</td>
                                        <td>
                                            <button class="btn btn-sm btn-outline--primary edit" 
                                                    data-id="{{ $plan->id }}" 
                                                    data-name="{{ $plan->name }}" 
                                                    data-price="{{ getAmount($plan->price) }}"
                                                    data-bv="{{ $plan->bv }}" 
                                                    data-ref_com="{{ getAmount($plan->ref_com) }}"
                                                    data-max_pairs_per_day="{{ $plan->max_pairs_per_day }}"
                                                    data-infinite_pairs="{{ $plan->infinite_pairs }}"
                                                    data-plan_picture="{{ asset('assets/images/plan/'.$plan->plan_picture) }}"
                                                    type="button">
                                                <i class="la la-pencil"></i> @lang('Edit')
                                            </button>

                                            @if ($plan->status == Status::DISABLE)
                                                <button class="btn btn-sm btn-outline--success confirmationBtn ms-1" 
                                                        data-question="@lang('Are you sure to enable this plan?')"
                                                        data-action="{{ route('admin.plan.status', $plan->id) }}">
                                                    <i class="la la-eye"></i> @lang('Enable')
                                                </button>
                                            @else
                                                <button class="btn btn-sm btn-outline--danger confirmationBtn ms-1" 
                                                        data-question="@lang('Are you sure to disable this plan?')"
                                                        data-action="{{ route('admin.plan.status', $plan->id) }}">
                                                    <i class="la la-eye-slash"></i> @lang('Disable')
                                                </button>
                                            @endif
                                        </td>
                                    </tr>
                                @empty
                                    <tr>
                                        <td class="text-muted text-center" colspan="100%">{{ __($emptyMessage) }}</td>
                                    </tr>
                                @endforelse
                            </tbody>
                        </table>
                    </div>
                </div>
                @if ($plans->hasPages())
                    <div class="card-footer py-4">
                        {{ $plans->links() }}
                    </div>
                @endif
            </div>
        </div>
    </div>

    {{-- Edit Plan Modal --}}
    <div class="modal fade" id="edit-plan" tabindex="-1">
        <div class="modal-dialog modal-dialog-centered modal-lg">
            <div class="modal-content">
                <div class="modal-header">
                    <h5 class="modal-title">@lang('Edit Plan')</h5>
                    <button class="close" data-bs-dismiss="modal" type="button">
                        <i class="las la-times"></i>
                    </button>
                </div>
                <form method="POST" action="{{ route('admin.plan.save') }}" enctype="multipart/form-data">
                    @csrf
                    <div class="modal-body">
                        <input class="form-control plan_id" name="id" type="hidden">
                        
                        <div class="row">
                            <div class="form-group col-md-6">
                                <label>@lang('Name')</label>
                                <input class="form-control name" name="name" type="text" required>
                            </div>
                            <div class="form-group col-md-6">
                                <label>@lang('Price')</label>
                                <input class="form-control price" name="price" type="number" step="any" required>
                            </div>
                        </div>

                        <div class="row">
                            <div class="form-group col-md-6">
                                <label>@lang('Business Volume (BV)')</label>
                                <input class="form-control bv" name="bv" type="number" required>
                            </div>
                            <div class="form-group col-md-6">
                                <label>@lang('Referral Commission')</label>
                                <input class="form-control ref_com" name="ref_com" type="number" step="any" required>
                            </div>
                        </div>

                        <div class="row">
                            <div class="form-group col-md-6">
                                <label>@lang('Max Pairs/Day')</label>
                                <input class="form-control max_pairs_per_day" name="max_pairs_per_day" type="number" step="any" required>
                            </div>
                            <div class="form-group col-md-6">
                                <label>@lang('Infinite Pairs')</label>
                                <input class="form-control infinite_pairs" name="infinite_pairs" type="number" step="any" required>
                            </div>
                        </div>

                        <div class="form-group">
                            <label>@lang('Plan Picture')</label>
                            <input class="form-control" name="plan_picture" type="file">
                            <img src="" alt="@lang('image')" class="w-80 img-thumbnail image-preview">
                        </div>
                    </div>

                    <div class="modal-footer">
                        <button class="btn btn--primary w-100" type="submit">@lang('Submit')</button>
                    </div>
                </form>
            </div>
        </div>
    </div>

    <x-confirmation-modal />
@endsection

@push('breadcrumb-plugins')
    <button class="btn btn-sm btn-outline--primary add-plan">
        <i class="la la-plus"></i>@lang('Add New')
    </button>
@endpush

@push('script')
<script>
    (function ($) {
        "use strict";

        let action = `{{ route('admin.plan.save') }}`;

        $('.edit').on('click', function() {
            let modal = $('#edit-plan');
            modal.find('.plan_id').val($(this).data('id'));
            modal.find('.name').val($(this).data('name'));
            modal.find('.price').val($(this).data('price'));
            modal.find('.bv').val($(this).data('bv'));
            modal.find('.ref_com').val($(this).data('ref_com'));
            modal.find('.max_pairs_per_day').val($(this).data('max_pairs_per_day'));
            modal.find('.infinite_pairs').val($(this).data('infinite_pairs'));

            let planPicture = $(this).data('plan_picture');
            if (planPicture) {
                modal.find('.image-preview').attr('src', planPicture);
            } else {
                modal.find('.image-preview').attr('src', '{{ asset("assets/images/plan/default.jpg") }}');
            }

            modal.find('form').attr('action', action);
            modal.modal('show');
        });

        $('.add-plan').on('click', function() {
            let modal = $('#edit-plan');
            modal.find('form')[0].reset();
            modal.find('.plan_id').val('');
            modal.find('.image-preview').attr('src', '{{ asset("assets/images/plan/default.jpg") }}');
            modal.find("form").attr('action', action);
            modal.modal('show');
        });

    })(jQuery);
</script>
@endpush
